@@ -254,6 +254,8 @@ def compute_amanuensis_data(csv_rows, low_percentage=0.1):
       latest_date = latest_month
     elif compute_percentage(earliest_date, latest_month, hours) >= low_percentage:
       latest_date = latest_month
+    else:
+      continue
 
     ta_data[ta] = (earliest_date, latest_date, hours)
 
